Documentation
¶
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Debug ¶
type Debug struct {
// contains filtered or unexported fields
}
func (Debug) Print1f ¶
Print1f prints the given message if the debug level is at least 1
Example ¶
d := NewDebug(true, false)
d.color = ""
d.Print1f("hello")
d.Print2f("hello2")
d.Print3f("hello3")
Output: Debug 1: hello
func (Debug) Print2f ¶
Print2f prints the given message if the debug level is at least 2
Example ¶
d := NewDebug(false, true)
d.color = ""
d.Print1f("hello")
d.Print2f("hello2")
d.Print3f("hello3")
Output: Debug 1: hello Debug 2: hello2
Click to show internal directories.
Click to hide internal directories.